@@ -27,6 +27,16 @@ def test_FUNC_json_WITH_test_dictionary_EXPECT_dictionary_returned() -> None:
     assert response == {'body': '{"test_key": "test_value"}', 'isBase64Encoded': False, 'statusCode': 200}
 
 
+def test_FUNC_json_WITH_test_empty_dictionary_EXPECT_dictionary_returned() -> None:
+    """
+    Test that the function can create an appropriate dictionary response from dictionary body.
+
+    :return: No return.
+    """
+    response = Response.json(200, body={})
+    assert response == {'body': '{}', 'isBase64Encoded': False, 'statusCode': 200}
+
+
 def test_FUNC_media_WITH_encoded_file_EXPECT_dictionary_returned() -> None:
     """
     Test that the function will return a byte64 encoded file.
